#include <stdio.h>
#include <stdlib.h>


/* Nodo di un albero binario. 
 * I puntatori ai figli sono nulli
 * nel caso i lnodo sia una foglia. */
typedef struct _nodo {
   int dato;
   struct _nodo *sx;
   struct _nodo *dx;
} nodo;


/* Struttura che rappresenta
 * il tipo di dato astratto 
 * Albero Binario Di Ricerca.
 *
 * Per ora contiene solo un puntatore
 * alla radice, NULL se l'albero e' vuoto.
 */
typedef struct  {
   nodo *radice;
} ABR;


void inserisci(ABR *punt_albero, int valore)
{
    nodo *nuovo = (nodo *)malloc(sizeof(nodo));
    nodo *corrente = NULL;
    nodo *figlio;
  
    nuovo->dato = valore;
    nuovo->sx = nuovo->dx = NULL;

    
    /* Cerchiamo il posto dove dobbiamo
     * inserirlo: percorriamo l'ABR
     * secondo il suo criterio di scelta,
     * tenendo un puntatore al prossimo
     * figlio in cui scendere. Quando
     * questo e' nullo, siamo ad
     * un ramo morto. */
    figlio = punt_albero->radice;
    while ( figlio != NULL )
    {
      corrente = figlio;
      if ( valore <= corrente->dato ) 
         figlio = corrente->sx;
      else
         figlio = corrente->dx;
    }

    /* Caso in cui l'albero e' vuoto: il nodo diventa
     * la radice. */
    if ( corrente == NULL ) 
      punt_albero->radice = nuovo;
    else /* Dobbiamo rifare il controllo per * capire da che parte agganciarci. */
      if ( valore <= corrente->dato  ) 
        corrente->sx = nuovo;	  
      else
        corrente->dx = nuovo;
}

/* Calcolo dell'altezza massima ricorsivamente */
int
max_altezza( nodo *n )
{
    int altezzasx, altezzadx;

    if ( n == NULL ) return 0;

    /* Controllo a sx e dx */
    altezzasx = max_altezza(n->sx);
    altezzadx = max_altezza(n->dx);

    /* Ritorno il massimo dei due, stando attento
     * ad aggiungere 1 perche' adesso viene incluso
     * il nodo corrente. */
    if ( altezzasx < altezzadx ) 
	return 1 + altezzadx;
    else
	return 1 + altezzasx;
}



int main()
{
    ABR albero;
    int i, N, val, pos;

    albero.radice = NULL;

    scanf("%d", &N);
    for ( i = 0; i < N; i++ ) 
    {
       scanf("%d", &val);
       inserisci(&albero, val);
    }
     
    printf("%d", max_altezza(albero.radice));
   
}
